@@ -4,7 +4,7 @@
 /****************************************************************************
 ** Meta object code from reading C++ file 'moc-files-dock-widget.h'
 **
-** Created by: The Qt Meta Object Compiler version 69 (Qt 6.10.1)
+** Created by: The Qt Meta Object Compiler version 69 (Qt 6.10.2)
 **
 ** WARNING! All changes made in this file will be lost!
 *****************************************************************************/
@@ -21,7 +21,7 @@
 #if !defined(Q_MOC_OUTPUT_REVISION)
 #error "The header file 'moc-files-dock-widget.h' doesn't include <QObject>."
 #elif Q_MOC_OUTPUT_REVISION != 69
-#error "This file was generated using the moc from 6.10.1. It"
+#error "This file was generated using the moc from 6.10.2. It"
 #error "cannot be used with the include files from this version of Qt."
 #error "(The moc has changed too much.)"
 #endif
@@ -34,14 +34,14 @@ QT_WARNING_PUSH
 QT_WARNING_DISABLE_DEPRECATED
 QT_WARNING_DISABLE_GCC("-Wuseless-cast")
 namespace {
-struct qt_meta_tag_ZN6octave17files_dock_widgetE_t {};
+struct qt_meta_tag_ZN6octave19file_system_browserE_t {};
 } // unnamed namespace
 
-template <> constexpr inline auto octave::files_dock_widget::qt_create_metaobjectdata<qt_meta_tag_ZN6octave17files_dock_widgetE_t>()
+template <> constexpr inline auto octave::file_system_browser::qt_create_metaobjectdata<qt_meta_tag_ZN6octave19file_system_browserE_t>()
 {
     namespace QMC = QtMocConstants;
     QtMocHelpers::StringRefStorage qt_stringData {
-        "octave::files_dock_widget",
+        "octave::file_system_browser",
         "open_file",
         "",
         "fileName",
@@ -285,22 +285,22 @@ template <> constexpr inline auto octave::files_dock_widget::qt_create_metaobjec
     };
     QtMocHelpers::UintData qt_enums {
     };
-    return QtMocHelpers::metaObjectData<files_dock_widget, qt_meta_tag_ZN6octave17files_dock_widgetE_t>(QMC::MetaObjectFlag{}, qt_stringData,
+    return QtMocHelpers::metaObjectData<file_system_browser, qt_meta_tag_ZN6octave19file_system_browserE_t>(QMC::MetaObjectFlag{}, qt_stringData,
             qt_methods, qt_properties, qt_enums);
 }
-Q_CONSTINIT const QMetaObject octave::files_dock_widget::staticMetaObject = { {
-    QMetaObject::SuperData::link<octave_dock_widget::staticMetaObject>(),
-    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6octave17files_dock_widgetE_t>.stringdata,
-    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6octave17files_dock_widgetE_t>.data,
+Q_CONSTINIT const QMetaObject octave::file_system_browser::staticMetaObject = { {
+    QMetaObject::SuperData::link<QWidget::staticMetaObject>(),
+    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6octave19file_system_browserE_t>.stringdata,
+    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6octave19file_system_browserE_t>.data,
     qt_static_metacall,
     nullptr,
-    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN6octave17files_dock_widgetE_t>.metaTypes,
+    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN6octave19file_system_browserE_t>.metaTypes,
     nullptr
 } };
 
-void octave::files_dock_widget::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
+void octave::file_system_browser::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
 {
-    auto *_t = static_cast<files_dock_widget *>(_o);
+    auto *_t = static_cast<file_system_browser *>(_o);
     if (_c == QMetaObject::InvokeMetaMethod) {
         switch (_id) {
         case 0: _t->open_file((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
@@ -355,27 +355,364 @@ void octave::files_dock_widget::qt_static_metacall(QObject *_o, QMetaObject::Cal
         }
     }
     if (_c == QMetaObject::IndexOfMethod) {
-        if (QtMocHelpers::indexOfMethod<void (files_dock_widget::*)(const QString & )>(_a, &files_dock_widget::open_file, 0))
+        if (QtMocHelpers::indexOfMethod<void (file_system_browser::*)(const QString & )>(_a, &file_system_browser::open_file, 0))
             return;
-        if (QtMocHelpers::indexOfMethod<void (files_dock_widget::*)(const QString & )>(_a, &files_dock_widget::displayed_directory_changed, 1))
+        if (QtMocHelpers::indexOfMethod<void (file_system_browser::*)(const QString & )>(_a, &file_system_browser::displayed_directory_changed, 1))
             return;
-        if (QtMocHelpers::indexOfMethod<void (files_dock_widget::*)(const QString & )>(_a, &files_dock_widget::load_file_signal, 2))
+        if (QtMocHelpers::indexOfMethod<void (file_system_browser::*)(const QString & )>(_a, &file_system_browser::load_file_signal, 2))
             return;
-        if (QtMocHelpers::indexOfMethod<void (files_dock_widget::*)(const QString & )>(_a, &files_dock_widget::open_any_signal, 3))
+        if (QtMocHelpers::indexOfMethod<void (file_system_browser::*)(const QString & )>(_a, &file_system_browser::open_any_signal, 3))
             return;
-        if (QtMocHelpers::indexOfMethod<void (files_dock_widget::*)(const QFileInfo & , int )>(_a, &files_dock_widget::run_file_signal, 4))
+        if (QtMocHelpers::indexOfMethod<void (file_system_browser::*)(const QFileInfo & , int )>(_a, &file_system_browser::run_file_signal, 4))
             return;
-        if (QtMocHelpers::indexOfMethod<void (files_dock_widget::*)(const QString & )>(_a, &files_dock_widget::find_files_signal, 5))
+        if (QtMocHelpers::indexOfMethod<void (file_system_browser::*)(const QString & )>(_a, &file_system_browser::find_files_signal, 5))
             return;
-        if (QtMocHelpers::indexOfMethod<void (files_dock_widget::*)(const QString & , const QString & )>(_a, &files_dock_widget::file_remove_signal, 6))
+        if (QtMocHelpers::indexOfMethod<void (file_system_browser::*)(const QString & , const QString & )>(_a, &file_system_browser::file_remove_signal, 6))
             return;
-        if (QtMocHelpers::indexOfMethod<void (files_dock_widget::*)(bool )>(_a, &files_dock_widget::file_renamed_signal, 7))
+        if (QtMocHelpers::indexOfMethod<void (file_system_browser::*)(bool )>(_a, &file_system_browser::file_renamed_signal, 7))
             return;
-        if (QtMocHelpers::indexOfMethod<void (files_dock_widget::*)(const QStringList & , bool , bool )>(_a, &files_dock_widget::modify_path_signal, 8))
+        if (QtMocHelpers::indexOfMethod<void (file_system_browser::*)(const QStringList & , bool , bool )>(_a, &file_system_browser::modify_path_signal, 8))
             return;
     }
 }
 
+const QMetaObject *octave::file_system_browser::metaObject() const
+{
+    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
+}
+
+void *octave::file_system_browser::qt_metacast(const char *_clname)
+{
+    if (!_clname) return nullptr;
+    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6octave19file_system_browserE_t>.strings))
+        return static_cast<void*>(this);
+    return QWidget::qt_metacast(_clname);
+}
+
+int octave::file_system_browser::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
+{
+    _id = QWidget::qt_metacall(_c, _id, _a);
+    if (_id < 0)
+        return _id;
+    if (_c == QMetaObject::InvokeMetaMethod) {
+        if (_id < 48)
+            qt_static_metacall(this, _c, _id, _a);
+        _id -= 48;
+    }
+    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
+        if (_id < 48)
+            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
+        _id -= 48;
+    }
+    return _id;
+}
+
+// SIGNAL 0
+void octave::file_system_browser::open_file(const QString & _t1)
+{
+    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
+}
+
+// SIGNAL 1
+void octave::file_system_browser::displayed_directory_changed(const QString & _t1)
+{
+    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
+}
+
+// SIGNAL 2
+void octave::file_system_browser::load_file_signal(const QString & _t1)
+{
+    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
+}
+
+// SIGNAL 3
+void octave::file_system_browser::open_any_signal(const QString & _t1)
+{
+    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
+}
+
+// SIGNAL 4
+void octave::file_system_browser::run_file_signal(const QFileInfo & _t1, int _t2)
+{
+    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1, _t2);
+}
+
+// SIGNAL 5
+void octave::file_system_browser::find_files_signal(const QString & _t1)
+{
+    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1);
+}
+
+// SIGNAL 6
+void octave::file_system_browser::file_remove_signal(const QString & _t1, const QString & _t2)
+{
+    QMetaObject::activate<void>(this, &staticMetaObject, 6, nullptr, _t1, _t2);
+}
+
+// SIGNAL 7
+void octave::file_system_browser::file_renamed_signal(bool _t1)
+{
+    QMetaObject::activate<void>(this, &staticMetaObject, 7, nullptr, _t1);
+}
+
+// SIGNAL 8
+void octave::file_system_browser::modify_path_signal(const QStringList & _t1, bool _t2, bool _t3)
+{
+    QMetaObject::activate<void>(this, &staticMetaObject, 8, nullptr, _t1, _t2, _t3);
+}
+namespace {
+struct qt_meta_tag_ZN6octave20editor_files_browserE_t {};
+} // unnamed namespace
+
+template <> constexpr inline auto octave::editor_files_browser::qt_create_metaobjectdata<qt_meta_tag_ZN6octave20editor_files_browserE_t>()
+{
+    namespace QMC = QtMocConstants;
+    QtMocHelpers::StringRefStorage qt_stringData {
+        "octave::editor_files_browser",
+        "focus_editor_file_signal",
+        "",
+        "file",
+        "close_editor_file_signal",
+        "files_to_remove",
+        "run_file_signal",
+        "QFileInfo",
+        "info",
+        "ops",
+        "displayed_directory_changed",
+        "dir",
+        "rename_editor_file",
+        "old_file",
+        "new_file",
+        "remove_editor_file",
+        "fname",
+        "contextmenu_requested",
+        "QPoint",
+        "pos",
+        "clicked",
+        "QModelIndex",
+        "index",
+        "notice_settings",
+        "save_settings",
+        "ctx_menu_close",
+        "ctx_menu_close_all",
+        "ctx_menu_run",
+        "ctx_menu_setcurrentdir"
+    };
+
+    QtMocHelpers::UintData qt_methods {
+        // Signal 'focus_editor_file_signal'
+        QtMocHelpers::SignalData<void(const QString &)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
+            { QMetaType::QString, 3 },
+        }}),
+        // Signal 'close_editor_file_signal'
+        QtMocHelpers::SignalData<void(const QStringList &)>(4, 2, QMC::AccessPublic, QMetaType::Void, {{
+            { QMetaType::QStringList, 5 },
+        }}),
+        // Signal 'run_file_signal'
+        QtMocHelpers::SignalData<void(const QFileInfo &, int)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
+            { 0x80000000 | 7, 8 }, { QMetaType::Int, 9 },
+        }}),
+        // Signal 'displayed_directory_changed'
+        QtMocHelpers::SignalData<void(const QString &)>(10, 2, QMC::AccessPublic, QMetaType::Void, {{
+            { QMetaType::QString, 11 },
+        }}),
+        // Slot 'rename_editor_file'
+        QtMocHelpers::SlotData<void(const QString &, const QString &)>(12, 2, QMC::AccessPublic, QMetaType::Void, {{
+            { QMetaType::QString, 13 }, { QMetaType::QString, 14 },
+        }}),
+        // Slot 'rename_editor_file'
+        QtMocHelpers::SlotData<void(const QString &)>(12, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
+            { QMetaType::QString, 13 },
+        }}),
+        // Slot 'remove_editor_file'
+        QtMocHelpers::SlotData<void(const QString &)>(15, 2, QMC::AccessPublic, QMetaType::Void, {{
+            { QMetaType::QString, 16 },
+        }}),
+        // Slot 'contextmenu_requested'
+        QtMocHelpers::SlotData<void(const QPoint &)>(17, 2, QMC::AccessPublic, QMetaType::Void, {{
+            { 0x80000000 | 18, 19 },
+        }}),
+        // Slot 'clicked'
+        QtMocHelpers::SlotData<void(const QModelIndex &)>(20, 2, QMC::AccessPublic, QMetaType::Void, {{
+            { 0x80000000 | 21, 22 },
+        }}),
+        // Slot 'notice_settings'
+        QtMocHelpers::SlotData<void()>(23, 2, QMC::AccessPublic, QMetaType::Void),
+        // Slot 'save_settings'
+        QtMocHelpers::SlotData<void()>(24, 2, QMC::AccessPublic, QMetaType::Void),
+        // Slot 'ctx_menu_close'
+        QtMocHelpers::SlotData<void(bool)>(25, 2, QMC::AccessPrivate, QMetaType::Void, {{
+            { QMetaType::Bool, 2 },
+        }}),
+        // Slot 'ctx_menu_close_all'
+        QtMocHelpers::SlotData<void(bool)>(26, 2, QMC::AccessPrivate, QMetaType::Void, {{
+            { QMetaType::Bool, 2 },
+        }}),
+        // Slot 'ctx_menu_run'
+        QtMocHelpers::SlotData<void(bool)>(27, 2, QMC::AccessPrivate, QMetaType::Void, {{
+            { QMetaType::Bool, 2 },
+        }}),
+        // Slot 'ctx_menu_setcurrentdir'
+        QtMocHelpers::SlotData<void(bool)>(28, 2, QMC::AccessPrivate, QMetaType::Void, {{
+            { QMetaType::Bool, 2 },
+        }}),
+    };
+    QtMocHelpers::UintData qt_properties {
+    };
+    QtMocHelpers::UintData qt_enums {
+    };
+    return QtMocHelpers::metaObjectData<editor_files_browser, qt_meta_tag_ZN6octave20editor_files_browserE_t>(QMC::MetaObjectFlag{}, qt_stringData,
+            qt_methods, qt_properties, qt_enums);
+}
+Q_CONSTINIT const QMetaObject octave::editor_files_browser::staticMetaObject = { {
+    QMetaObject::SuperData::link<QWidget::staticMetaObject>(),
+    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6octave20editor_files_browserE_t>.stringdata,
+    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6octave20editor_files_browserE_t>.data,
+    qt_static_metacall,
+    nullptr,
+    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN6octave20editor_files_browserE_t>.metaTypes,
+    nullptr
+} };
+
+void octave::editor_files_browser::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
+{
+    auto *_t = static_cast<editor_files_browser *>(_o);
+    if (_c == QMetaObject::InvokeMetaMethod) {
+        switch (_id) {
+        case 0: _t->focus_editor_file_signal((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
+        case 1: _t->close_editor_file_signal((*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[1]))); break;
+        case 2: _t->run_file_signal((*reinterpret_cast<std::add_pointer_t<QFileInfo>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
+        case 3: _t->displayed_directory_changed((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
+        case 4: _t->rename_editor_file((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
+        case 5: _t->rename_editor_file((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
+        case 6: _t->remove_editor_file((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
+        case 7: _t->contextmenu_requested((*reinterpret_cast<std::add_pointer_t<QPoint>>(_a[1]))); break;
+        case 8: _t->clicked((*reinterpret_cast<std::add_pointer_t<QModelIndex>>(_a[1]))); break;
+        case 9: _t->notice_settings(); break;
+        case 10: _t->save_settings(); break;
+        case 11: _t->ctx_menu_close((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
+        case 12: _t->ctx_menu_close_all((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
+        case 13: _t->ctx_menu_run((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
+        case 14: _t->ctx_menu_setcurrentdir((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
+        default: ;
+        }
+    }
+    if (_c == QMetaObject::IndexOfMethod) {
+        if (QtMocHelpers::indexOfMethod<void (editor_files_browser::*)(const QString & )>(_a, &editor_files_browser::focus_editor_file_signal, 0))
+            return;
+        if (QtMocHelpers::indexOfMethod<void (editor_files_browser::*)(const QStringList & )>(_a, &editor_files_browser::close_editor_file_signal, 1))
+            return;
+        if (QtMocHelpers::indexOfMethod<void (editor_files_browser::*)(const QFileInfo & , int )>(_a, &editor_files_browser::run_file_signal, 2))
+            return;
+        if (QtMocHelpers::indexOfMethod<void (editor_files_browser::*)(const QString & )>(_a, &editor_files_browser::displayed_directory_changed, 3))
+            return;
+    }
+}
+
+const QMetaObject *octave::editor_files_browser::metaObject() const
+{
+    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
+}
+
+void *octave::editor_files_browser::qt_metacast(const char *_clname)
+{
+    if (!_clname) return nullptr;
+    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6octave20editor_files_browserE_t>.strings))
+        return static_cast<void*>(this);
+    return QWidget::qt_metacast(_clname);
+}
+
+int octave::editor_files_browser::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
+{
+    _id = QWidget::qt_metacall(_c, _id, _a);
+    if (_id < 0)
+        return _id;
+    if (_c == QMetaObject::InvokeMetaMethod) {
+        if (_id < 15)
+            qt_static_metacall(this, _c, _id, _a);
+        _id -= 15;
+    }
+    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
+        if (_id < 15)
+            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
+        _id -= 15;
+    }
+    return _id;
+}
+
+// SIGNAL 0
+void octave::editor_files_browser::focus_editor_file_signal(const QString & _t1)
+{
+    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
+}
+
+// SIGNAL 1
+void octave::editor_files_browser::close_editor_file_signal(const QStringList & _t1)
+{
+    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
+}
+
+// SIGNAL 2
+void octave::editor_files_browser::run_file_signal(const QFileInfo & _t1, int _t2)
+{
+    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1, _t2);
+}
+
+// SIGNAL 3
+void octave::editor_files_browser::displayed_directory_changed(const QString & _t1)
+{
+    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
+}
+namespace {
+struct qt_meta_tag_ZN6octave17files_dock_widgetE_t {};
+} // unnamed namespace
+
+template <> constexpr inline auto octave::files_dock_widget::qt_create_metaobjectdata<qt_meta_tag_ZN6octave17files_dock_widgetE_t>()
+{
+    namespace QMC = QtMocConstants;
+    QtMocHelpers::StringRefStorage qt_stringData {
+        "octave::files_dock_widget",
+        "notice_settings",
+        "",
+        "save_settings"
+    };
+
+    QtMocHelpers::UintData qt_methods {
+        // Slot 'notice_settings'
+        QtMocHelpers::SlotData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
+        // Slot 'save_settings'
+        QtMocHelpers::SlotData<void()>(3, 2, QMC::AccessPublic, QMetaType::Void),
+    };
+    QtMocHelpers::UintData qt_properties {
+    };
+    QtMocHelpers::UintData qt_enums {
+    };
+    return QtMocHelpers::metaObjectData<files_dock_widget, qt_meta_tag_ZN6octave17files_dock_widgetE_t>(QMC::MetaObjectFlag{}, qt_stringData,
+            qt_methods, qt_properties, qt_enums);
+}
+Q_CONSTINIT const QMetaObject octave::files_dock_widget::staticMetaObject = { {
+    QMetaObject::SuperData::link<octave_dock_widget::staticMetaObject>(),
+    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6octave17files_dock_widgetE_t>.stringdata,
+    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6octave17files_dock_widgetE_t>.data,
+    qt_static_metacall,
+    nullptr,
+    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN6octave17files_dock_widgetE_t>.metaTypes,
+    nullptr
+} };
+
+void octave::files_dock_widget::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
+{
+    auto *_t = static_cast<files_dock_widget *>(_o);
+    if (_c == QMetaObject::InvokeMetaMethod) {
+        switch (_id) {
+        case 0: _t->notice_settings(); break;
+        case 1: _t->save_settings(); break;
+        default: ;
+        }
+    }
+    (void)_a;
+}
+
 const QMetaObject *octave::files_dock_widget::metaObject() const
 {
     return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
@@ -395,69 +732,15 @@ int octave::files_dock_widget::qt_metacall(QMetaObject::Call _c, int _id, void *
     if (_id < 0)
         return _id;
     if (_c == QMetaObject::InvokeMetaMethod) {
-        if (_id < 48)
+        if (_id < 2)
             qt_static_metacall(this, _c, _id, _a);
-        _id -= 48;
+        _id -= 2;
     }
     if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
-        if (_id < 48)
+        if (_id < 2)
             *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
-        _id -= 48;
+        _id -= 2;
     }
     return _id;
 }
-
-// SIGNAL 0
-void octave::files_dock_widget::open_file(const QString & _t1)
-{
-    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
-}
-
-// SIGNAL 1
-void octave::files_dock_widget::displayed_directory_changed(const QString & _t1)
-{
-    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
-}
-
-// SIGNAL 2
-void octave::files_dock_widget::load_file_signal(const QString & _t1)
-{
-    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
-}
-
-// SIGNAL 3
-void octave::files_dock_widget::open_any_signal(const QString & _t1)
-{
-    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
-}
-
-// SIGNAL 4
-void octave::files_dock_widget::run_file_signal(const QFileInfo & _t1, int _t2)
-{
-    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1, _t2);
-}
-
-// SIGNAL 5
-void octave::files_dock_widget::find_files_signal(const QString & _t1)
-{
-    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1);
-}
-
-// SIGNAL 6
-void octave::files_dock_widget::file_remove_signal(const QString & _t1, const QString & _t2)
-{
-    QMetaObject::activate<void>(this, &staticMetaObject, 6, nullptr, _t1, _t2);
-}
-
-// SIGNAL 7
-void octave::files_dock_widget::file_renamed_signal(bool _t1)
-{
-    QMetaObject::activate<void>(this, &staticMetaObject, 7, nullptr, _t1);
-}
-
-// SIGNAL 8
-void octave::files_dock_widget::modify_path_signal(const QStringList & _t1, bool _t2, bool _t3)
-{
-    QMetaObject::activate<void>(this, &staticMetaObject, 8, nullptr, _t1, _t2, _t3);
-}
 QT_WARNING_POP
