@@ -4,7 +4,7 @@
 /****************************************************************************
 ** Meta object code from reading C++ file 'moc-main-window.h'
 **
-** Created by: The Qt Meta Object Compiler version 69 (Qt 6.10.1)
+** Created by: The Qt Meta Object Compiler version 69 (Qt 6.10.2)
 **
 ** WARNING! All changes made in this file will be lost!
 *****************************************************************************/
@@ -22,7 +22,7 @@
 #if !defined(Q_MOC_OUTPUT_REVISION)
 #error "The header file 'moc-main-window.h' doesn't include <QObject>."
 #elif Q_MOC_OUTPUT_REVISION != 69
-#error "This file was generated using the moc from 6.10.1. It"
+#error "This file was generated using the moc from 6.10.2. It"
 #error "cannot be used with the include files from this version of Qt."
 #error "(The moc has changed too much.)"
 #endif
@@ -119,8 +119,6 @@ template <> constexpr inline auto octave::main_window::qt_create_metaobjectdata<
         "show_about_octave",
         "notice_settings",
         "update_by_worker",
-        "getFusionDarkPalette",
-        "QPalette",
         "prepare_to_exit",
         "go_to_previous_widget",
         "reset_windows",
@@ -354,168 +352,166 @@ template <> constexpr inline auto octave::main_window::qt_create_metaobjectdata<
         }}),
         // Slot 'notice_settings'
         QtMocHelpers::SlotData<void()>(75, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void),
-        // Slot 'getFusionDarkPalette'
-        QtMocHelpers::SlotData<QPalette()>(77, 2, QMC::AccessPublic, 0x80000000 | 78),
         // Slot 'prepare_to_exit'
-        QtMocHelpers::SlotData<void()>(79, 2, QMC::AccessPublic, QMetaType::Void),
+        QtMocHelpers::SlotData<void()>(77, 2, QMC::AccessPublic, QMetaType::Void),
         // Slot 'go_to_previous_widget'
-        QtMocHelpers::SlotData<void()>(80, 2, QMC::AccessPublic, QMetaType::Void),
+        QtMocHelpers::SlotData<void()>(78, 2, QMC::AccessPublic, QMetaType::Void),
         // Slot 'reset_windows'
-        QtMocHelpers::SlotData<void()>(81, 2, QMC::AccessPublic, QMetaType::Void),
+        QtMocHelpers::SlotData<void()>(79, 2, QMC::AccessPublic, QMetaType::Void),
         // Slot 'do_reset_windows'
-        QtMocHelpers::SlotData<void(bool, bool, bool)>(82, 2, QMC::AccessPublic, QMetaType::Void, {{
-            { QMetaType::Bool, 83 }, { QMetaType::Bool, 84 }, { QMetaType::Bool, 85 },
+        QtMocHelpers::SlotData<void(bool, bool, bool)>(80, 2, QMC::AccessPublic, QMetaType::Void, {{
+            { QMetaType::Bool, 81 }, { QMetaType::Bool, 82 }, { QMetaType::Bool, 83 },
         }}),
         // Slot 'do_reset_windows'
-        QtMocHelpers::SlotData<void(bool, bool)>(82, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
-            { QMetaType::Bool, 83 }, { QMetaType::Bool, 84 },
+        QtMocHelpers::SlotData<void(bool, bool)>(80, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
+            { QMetaType::Bool, 81 }, { QMetaType::Bool, 82 },
         }}),
         // Slot 'do_reset_windows'
-        QtMocHelpers::SlotData<void(bool)>(82, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
-            { QMetaType::Bool, 83 },
+        QtMocHelpers::SlotData<void(bool)>(80, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
+            { QMetaType::Bool, 81 },
         }}),
         // Slot 'do_reset_windows'
-        QtMocHelpers::SlotData<void()>(82, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void),
+        QtMocHelpers::SlotData<void()>(80, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void),
         // Slot 'update_octave_directory'
-        QtMocHelpers::SlotData<void(const QString &)>(86, 2, QMC::AccessPublic, QMetaType::Void, {{
-            { QMetaType::QString, 87 },
+        QtMocHelpers::SlotData<void(const QString &)>(84, 2, QMC::AccessPublic, QMetaType::Void, {{
+            { QMetaType::QString, 85 },
         }}),
         // Slot 'browse_for_directory'
-        QtMocHelpers::SlotData<void()>(88, 2, QMC::AccessPublic, QMetaType::Void),
+        QtMocHelpers::SlotData<void()>(86, 2, QMC::AccessPublic, QMetaType::Void),
         // Slot 'set_current_working_directory'
-        QtMocHelpers::SlotData<void(const QString &)>(89, 2, QMC::AccessPublic, QMetaType::Void, {{
-            { QMetaType::QString, 87 },
+        QtMocHelpers::SlotData<void(const QString &)>(87, 2, QMC::AccessPublic, QMetaType::Void, {{
+            { QMetaType::QString, 85 },
         }}),
         // Slot 'change_directory_up'
-        QtMocHelpers::SlotData<void()>(90, 2, QMC::AccessPublic, QMetaType::Void),
+        QtMocHelpers::SlotData<void()>(88, 2, QMC::AccessPublic, QMetaType::Void),
         // Slot 'accept_directory_line_edit'
-        QtMocHelpers::SlotData<void()>(91, 2, QMC::AccessPublic, QMetaType::Void),
+        QtMocHelpers::SlotData<void()>(89, 2, QMC::AccessPublic, QMetaType::Void),
         // Slot 'execute_command_in_terminal'
-        QtMocHelpers::SlotData<void(const QString &)>(92, 2, QMC::AccessPublic, QMetaType::Void, {{
-            { QMetaType::QString, 87 },
+        QtMocHelpers::SlotData<void(const QString &)>(90, 2, QMC::AccessPublic, QMetaType::Void, {{
+            { QMetaType::QString, 85 },
         }}),
         // Slot 'run_file_in_terminal'
-        QtMocHelpers::SlotData<void(const QFileInfo &, int)>(93, 2, QMC::AccessPublic, QMetaType::Void, {{
-            { 0x80000000 | 94, 95 }, { QMetaType::Int, 96 },
+        QtMocHelpers::SlotData<void(const QFileInfo &, int)>(91, 2, QMC::AccessPublic, QMetaType::Void, {{
+            { 0x80000000 | 92, 93 }, { QMetaType::Int, 94 },
         }}),
         // Slot 'handle_new_figure_request'
-        QtMocHelpers::SlotData<void()>(97, 2, QMC::AccessPublic, QMetaType::Void),
+        QtMocHelpers::SlotData<void()>(95, 2, QMC::AccessPublic, QMetaType::Void),
         // Slot 'handle_enter_debugger'
-        QtMocHelpers::SlotData<void()>(98, 2, QMC::AccessPublic, QMetaType::Void),
+        QtMocHelpers::SlotData<void()>(96, 2, QMC::AccessPublic, QMetaType::Void),
         // Slot 'handle_exit_debugger'
-        QtMocHelpers::SlotData<void()>(99, 2, QMC::AccessPublic, QMetaType::Void),
+        QtMocHelpers::SlotData<void()>(97, 2, QMC::AccessPublic, QMetaType::Void),
         // Slot 'debug_continue'
-        QtMocHelpers::SlotData<void()>(100, 2, QMC::AccessPublic, QMetaType::Void),
+        QtMocHelpers::SlotData<void()>(98, 2, QMC::AccessPublic, QMetaType::Void),
         // Slot 'debug_step_into'
-        QtMocHelpers::SlotData<void()>(101, 2, QMC::AccessPublic, QMetaType::Void),
+        QtMocHelpers::SlotData<void()>(99, 2, QMC::AccessPublic, QMetaType::Void),
         // Slot 'debug_step_over'
-        QtMocHelpers::SlotData<void()>(102, 2, QMC::AccessPublic, QMetaType::Void),
+        QtMocHelpers::SlotData<void()>(100, 2, QMC::AccessPublic, QMetaType::Void),
         // Slot 'debug_step_out'
-        QtMocHelpers::SlotData<void()>(103, 2, QMC::AccessPublic, QMetaType::Void),
+        QtMocHelpers::SlotData<void()>(101, 2, QMC::AccessPublic, QMetaType::Void),
         // Slot 'debug_quit'
-        QtMocHelpers::SlotData<void()>(104, 2, QMC::AccessPublic, QMetaType::Void),
+        QtMocHelpers::SlotData<void()>(102, 2, QMC::AccessPublic, QMetaType::Void),
         // Slot 'editor_tabs_changed'
-        QtMocHelpers::SlotData<void(bool, bool)>(105, 2, QMC::AccessPublic, QMetaType::Void, {{
+        QtMocHelpers::SlotData<void(bool, bool)>(103, 2, QMC::AccessPublic, QMetaType::Void, {{
             { QMetaType::Bool, 2 }, { QMetaType::Bool, 2 },
         }}),
         // Slot 'request_open_file'
-        QtMocHelpers::SlotData<void()>(106, 2, QMC::AccessPublic, QMetaType::Void),
+        QtMocHelpers::SlotData<void()>(104, 2, QMC::AccessPublic, QMetaType::Void),
         // Slot 'request_new_script'
-        QtMocHelpers::SlotData<void(const QString &)>(107, 2, QMC::AccessPublic, QMetaType::Void, {{
-            { QMetaType::QString, 108 },
+        QtMocHelpers::SlotData<void(const QString &)>(105, 2, QMC::AccessPublic, QMetaType::Void, {{
+            { QMetaType::QString, 106 },
         }}),
         // Slot 'request_new_script'
+        QtMocHelpers::SlotData<void()>(105, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void),
+        // Slot 'request_new_function'
+        QtMocHelpers::SlotData<void(bool)>(107, 2, QMC::AccessPublic, QMetaType::Void, {{
+            { QMetaType::Bool, 108 },
+        }}),
+        // Slot 'request_new_function'
         QtMocHelpers::SlotData<void()>(107, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void),
-        // Slot 'request_new_function'
-        QtMocHelpers::SlotData<void(bool)>(109, 2, QMC::AccessPublic, QMetaType::Void, {{
-            { QMetaType::Bool, 110 },
-        }}),
-        // Slot 'request_new_function'
-        QtMocHelpers::SlotData<void()>(109, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void),
         // Slot 'handle_edit_mfile_request'
-        QtMocHelpers::SlotData<void(const QString &, const QString &, const QString &, int)>(111, 2, QMC::AccessPublic, QMetaType::Void, {{
-            { QMetaType::QString, 112 }, { QMetaType::QString, 11 }, { QMetaType::QString, 113 }, { QMetaType::Int, 13 },
+        QtMocHelpers::SlotData<void(const QString &, const QString &, const QString &, int)>(109, 2, QMC::AccessPublic, QMetaType::Void, {{
+            { QMetaType::QString, 110 }, { QMetaType::QString, 11 }, { QMetaType::QString, 111 }, { QMetaType::Int, 13 },
         }}),
         // Slot 'handle_insert_debugger_pointer_request'
-        QtMocHelpers::SlotData<void(const QString &, int)>(114, 2, QMC::AccessPublic, QMetaType::Void, {{
+        QtMocHelpers::SlotData<void(const QString &, int)>(112, 2, QMC::AccessPublic, QMetaType::Void, {{
             { QMetaType::QString, 11 }, { QMetaType::Int, 13 },
         }}),
         // Slot 'handle_delete_debugger_pointer_request'
-        QtMocHelpers::SlotData<void(const QString &, int)>(115, 2, QMC::AccessPublic, QMetaType::Void, {{
+        QtMocHelpers::SlotData<void(const QString &, int)>(113, 2, QMC::AccessPublic, QMetaType::Void, {{
             { QMetaType::QString, 11 }, { QMetaType::Int, 13 },
         }}),
         // Slot 'handle_update_breakpoint_marker_request'
-        QtMocHelpers::SlotData<void(bool, const QString &, int, const QString &)>(116, 2, QMC::AccessPublic, QMetaType::Void, {{
+        QtMocHelpers::SlotData<void(bool, const QString &, int, const QString &)>(114, 2, QMC::AccessPublic, QMetaType::Void, {{
             { QMetaType::Bool, 22 }, { QMetaType::QString, 11 }, { QMetaType::Int, 13 }, { QMetaType::QString, 23 },
         }}),
         // Slot 'read_settings'
-        QtMocHelpers::SlotData<void()>(117, 2, QMC::AccessPublic, QMetaType::Void),
+        QtMocHelpers::SlotData<void()>(115, 2, QMC::AccessPublic, QMetaType::Void),
         // Slot 'init_terminal_size'
-        QtMocHelpers::SlotData<void()>(118, 2, QMC::AccessPublic, QMetaType::Void),
+        QtMocHelpers::SlotData<void()>(116, 2, QMC::AccessPublic, QMetaType::Void),
         // Slot 'set_window_layout'
-        QtMocHelpers::SlotData<void()>(119, 2, QMC::AccessPublic, QMetaType::Void),
+        QtMocHelpers::SlotData<void()>(117, 2, QMC::AccessPublic, QMetaType::Void),
         // Slot 'write_settings'
-        QtMocHelpers::SlotData<void()>(120, 2, QMC::AccessPublic, QMetaType::Void),
+        QtMocHelpers::SlotData<void()>(118, 2, QMC::AccessPublic, QMetaType::Void),
         // Slot 'copyClipboard'
-        QtMocHelpers::SlotData<void()>(121, 2, QMC::AccessPublic, QMetaType::Void),
+        QtMocHelpers::SlotData<void()>(119, 2, QMC::AccessPublic, QMetaType::Void),
         // Slot 'pasteClipboard'
-        QtMocHelpers::SlotData<void()>(122, 2, QMC::AccessPublic, QMetaType::Void),
+        QtMocHelpers::SlotData<void()>(120, 2, QMC::AccessPublic, QMetaType::Void),
         // Slot 'selectAll'
-        QtMocHelpers::SlotData<void()>(123, 2, QMC::AccessPublic, QMetaType::Void),
+        QtMocHelpers::SlotData<void()>(121, 2, QMC::AccessPublic, QMetaType::Void),
         // Slot 'handle_gui_status_update'
-        QtMocHelpers::SlotData<void(const QString &, const QString &)>(124, 2, QMC::AccessPublic, QMetaType::Void, {{
-            { QMetaType::QString, 125 }, { QMetaType::QString, 126 },
+        QtMocHelpers::SlotData<void(const QString &, const QString &)>(122, 2, QMC::AccessPublic, QMetaType::Void, {{
+            { QMetaType::QString, 123 }, { QMetaType::QString, 124 },
         }}),
         // Slot 'focus_console_after_command'
-        QtMocHelpers::SlotData<void()>(127, 2, QMC::AccessPublic, QMetaType::Void),
+        QtMocHelpers::SlotData<void()>(125, 2, QMC::AccessPublic, QMetaType::Void),
         // Slot 'profiler_session'
-        QtMocHelpers::SlotData<void()>(128, 2, QMC::AccessPublic, QMetaType::Void),
+        QtMocHelpers::SlotData<void()>(126, 2, QMC::AccessPublic, QMetaType::Void),
         // Slot 'profiler_session_resume'
-        QtMocHelpers::SlotData<void()>(129, 2, QMC::AccessPublic, QMetaType::Void),
+        QtMocHelpers::SlotData<void()>(127, 2, QMC::AccessPublic, QMetaType::Void),
         // Slot 'profiler_stop'
-        QtMocHelpers::SlotData<void()>(130, 2, QMC::AccessPublic, QMetaType::Void),
+        QtMocHelpers::SlotData<void()>(128, 2, QMC::AccessPublic, QMetaType::Void),
         // Slot 'handle_profiler_status_update'
-        QtMocHelpers::SlotData<void(bool)>(131, 2, QMC::AccessPublic, QMetaType::Void, {{
+        QtMocHelpers::SlotData<void(bool)>(129, 2, QMC::AccessPublic, QMetaType::Void, {{
             { QMetaType::Bool, 2 },
         }}),
         // Slot 'profiler_show'
-        QtMocHelpers::SlotData<void()>(132, 2, QMC::AccessPublic, QMetaType::Void),
+        QtMocHelpers::SlotData<void()>(130, 2, QMC::AccessPublic, QMetaType::Void),
         // Slot 'handle_octave_ready'
-        QtMocHelpers::SlotData<void()>(133, 2, QMC::AccessPublic, QMetaType::Void),
+        QtMocHelpers::SlotData<void()>(131, 2, QMC::AccessPublic, QMetaType::Void),
         // Slot 'handle_set_path_dialog_request'
-        QtMocHelpers::SlotData<void()>(134, 2, QMC::AccessPublic, QMetaType::Void),
+        QtMocHelpers::SlotData<void()>(132, 2, QMC::AccessPublic, QMetaType::Void),
         // Slot 'find_files'
-        QtMocHelpers::SlotData<void(const QString &)>(135, 2, QMC::AccessPublic, QMetaType::Void, {{
-            { QMetaType::QString, 136 },
+        QtMocHelpers::SlotData<void(const QString &)>(133, 2, QMC::AccessPublic, QMetaType::Void, {{
+            { QMetaType::QString, 134 },
         }}),
         // Slot 'find_files'
-        QtMocHelpers::SlotData<void()>(135, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void),
+        QtMocHelpers::SlotData<void()>(133, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void),
         // Slot 'find_files_finished'
-        QtMocHelpers::SlotData<void(int)>(137, 2, QMC::AccessPublic, QMetaType::Void, {{
+        QtMocHelpers::SlotData<void(int)>(135, 2, QMC::AccessPublic, QMetaType::Void, {{
             { QMetaType::Int, 2 },
         }}),
         // Slot 'set_screen_size'
-        QtMocHelpers::SlotData<void(int, int)>(138, 2, QMC::AccessPublic, QMetaType::Void, {{
-            { QMetaType::Int, 139 }, { QMetaType::Int, 140 },
+        QtMocHelpers::SlotData<void(int, int)>(136, 2, QMC::AccessPublic, QMetaType::Void, {{
+            { QMetaType::Int, 137 }, { QMetaType::Int, 138 },
         }}),
         // Slot 'clipboard_has_changed'
-        QtMocHelpers::SlotData<void()>(141, 2, QMC::AccessPublic, QMetaType::Void),
+        QtMocHelpers::SlotData<void()>(139, 2, QMC::AccessPublic, QMetaType::Void),
         // Slot 'clear_clipboard'
-        QtMocHelpers::SlotData<void()>(142, 2, QMC::AccessPublic, QMetaType::Void),
+        QtMocHelpers::SlotData<void()>(140, 2, QMC::AccessPublic, QMetaType::Void),
         // Slot 'get_dock_widget_list'
-        QtMocHelpers::SlotData<QList<octave_dock_widget*>()>(143, 2, QMC::AccessPublic, 0x80000000 | 144),
+        QtMocHelpers::SlotData<QList<octave_dock_widget*>()>(141, 2, QMC::AccessPublic, 0x80000000 | 142),
         // Slot 'disable_menu_shortcuts'
-        QtMocHelpers::SlotData<void(bool)>(145, 2, QMC::AccessPrivate, QMetaType::Void, {{
-            { QMetaType::Bool, 146 },
+        QtMocHelpers::SlotData<void(bool)>(143, 2, QMC::AccessPrivate, QMetaType::Void, {{
+            { QMetaType::Bool, 144 },
         }}),
         // Slot 'restore_create_file_setting'
-        QtMocHelpers::SlotData<void()>(147, 2, QMC::AccessPrivate, QMetaType::Void),
+        QtMocHelpers::SlotData<void()>(145, 2, QMC::AccessPrivate, QMetaType::Void),
         // Slot 'set_file_encoding'
-        QtMocHelpers::SlotData<void(const QString &)>(148, 2, QMC::AccessPrivate, QMetaType::Void, {{
-            { QMetaType::QString, 149 },
+        QtMocHelpers::SlotData<void(const QString &)>(146, 2, QMC::AccessPrivate, QMetaType::Void, {{
+            { QMetaType::QString, 147 },
         }}),
         // Slot 'warning_function_not_found'
-        QtMocHelpers::SlotData<void(const QString &)>(150, 2, QMC::AccessPrivate, QMetaType::Void, {{
+        QtMocHelpers::SlotData<void(const QString &)>(148, 2, QMC::AccessPrivate, QMetaType::Void, {{
             { QMetaType::QString, 32 },
         }}),
     };
@@ -594,68 +590,66 @@ void octave::main_window::qt_static_metacall(QObject *_o, QMetaObject::Call _c,
         case 50: _t->show_about_octave(); break;
         case 51: _t->notice_settings((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
         case 52: _t->notice_settings(); break;
-        case 53: { QPalette _r = _t->getFusionDarkPalette();
-            if (_a[0]) *reinterpret_cast<QPalette*>(_a[0]) = std::move(_r); }  break;
-        case 54: _t->prepare_to_exit(); break;
-        case 55: _t->go_to_previous_widget(); break;
-        case 56: _t->reset_windows(); break;
-        case 57: _t->do_reset_windows((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[3]))); break;
-        case 58: _t->do_reset_windows((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
-        case 59: _t->do_reset_windows((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
-        case 60: _t->do_reset_windows(); break;
-        case 61: _t->update_octave_directory((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
-        case 62: _t->browse_for_directory(); break;
-        case 63: _t->set_current_working_directory((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
-        case 64: _t->change_directory_up(); break;
-        case 65: _t->accept_directory_line_edit(); break;
-        case 66: _t->execute_command_in_terminal((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
-        case 67: _t->run_file_in_terminal((*reinterpret_cast<std::add_pointer_t<QFileInfo>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
-        case 68: _t->handle_new_figure_request(); break;
-        case 69: _t->handle_enter_debugger(); break;
-        case 70: _t->handle_exit_debugger(); break;
-        case 71: _t->debug_continue(); break;
-        case 72: _t->debug_step_into(); break;
-        case 73: _t->debug_step_over(); break;
-        case 74: _t->debug_step_out(); break;
-        case 75: _t->debug_quit(); break;
-        case 76: _t->editor_tabs_changed((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
-        case 77: _t->request_open_file(); break;
-        case 78: _t->request_new_script((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
-        case 79: _t->request_new_script(); break;
-        case 80: _t->request_new_function((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
-        case 81: _t->request_new_function(); break;
-        case 82: _t->handle_edit_mfile_request((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[4]))); break;
-        case 83: _t->handle_insert_debugger_pointer_request((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
-        case 84: _t->handle_delete_debugger_pointer_request((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
-        case 85: _t->handle_update_breakpoint_marker_request((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[4]))); break;
-        case 86: _t->read_settings(); break;
-        case 87: _t->init_terminal_size(); break;
-        case 88: _t->set_window_layout(); break;
-        case 89: _t->write_settings(); break;
-        case 90: _t->copyClipboard(); break;
-        case 91: _t->pasteClipboard(); break;
-        case 92: _t->selectAll(); break;
-        case 93: _t->handle_gui_status_update((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
-        case 94: _t->focus_console_after_command(); break;
-        case 95: _t->profiler_session(); break;
-        case 96: _t->profiler_session_resume(); break;
-        case 97: _t->profiler_stop(); break;
-        case 98: _t->handle_profiler_status_update((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
-        case 99: _t->profiler_show(); break;
-        case 100: _t->handle_octave_ready(); break;
-        case 101: _t->handle_set_path_dialog_request(); break;
-        case 102: _t->find_files((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
-        case 103: _t->find_files(); break;
-        case 104: _t->find_files_finished((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
-        case 105: _t->set_screen_size((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
-        case 106: _t->clipboard_has_changed(); break;
-        case 107: _t->clear_clipboard(); break;
-        case 108: { QList<octave_dock_widget*> _r = _t->get_dock_widget_list();
+        case 53: _t->prepare_to_exit(); break;
+        case 54: _t->go_to_previous_widget(); break;
+        case 55: _t->reset_windows(); break;
+        case 56: _t->do_reset_windows((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[3]))); break;
+        case 57: _t->do_reset_windows((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
+        case 58: _t->do_reset_windows((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
+        case 59: _t->do_reset_windows(); break;
+        case 60: _t->update_octave_directory((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
+        case 61: _t->browse_for_directory(); break;
+        case 62: _t->set_current_working_directory((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
+        case 63: _t->change_directory_up(); break;
+        case 64: _t->accept_directory_line_edit(); break;
+        case 65: _t->execute_command_in_terminal((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
+        case 66: _t->run_file_in_terminal((*reinterpret_cast<std::add_pointer_t<QFileInfo>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
+        case 67: _t->handle_new_figure_request(); break;
+        case 68: _t->handle_enter_debugger(); break;
+        case 69: _t->handle_exit_debugger(); break;
+        case 70: _t->debug_continue(); break;
+        case 71: _t->debug_step_into(); break;
+        case 72: _t->debug_step_over(); break;
+        case 73: _t->debug_step_out(); break;
+        case 74: _t->debug_quit(); break;
+        case 75: _t->editor_tabs_changed((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
+        case 76: _t->request_open_file(); break;
+        case 77: _t->request_new_script((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
+        case 78: _t->request_new_script(); break;
+        case 79: _t->request_new_function((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
+        case 80: _t->request_new_function(); break;
+        case 81: _t->handle_edit_mfile_request((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[4]))); break;
+        case 82: _t->handle_insert_debugger_pointer_request((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
+        case 83: _t->handle_delete_debugger_pointer_request((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
+        case 84: _t->handle_update_breakpoint_marker_request((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[4]))); break;
+        case 85: _t->read_settings(); break;
+        case 86: _t->init_terminal_size(); break;
+        case 87: _t->set_window_layout(); break;
+        case 88: _t->write_settings(); break;
+        case 89: _t->copyClipboard(); break;
+        case 90: _t->pasteClipboard(); break;
+        case 91: _t->selectAll(); break;
+        case 92: _t->handle_gui_status_update((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
+        case 93: _t->focus_console_after_command(); break;
+        case 94: _t->profiler_session(); break;
+        case 95: _t->profiler_session_resume(); break;
+        case 96: _t->profiler_stop(); break;
+        case 97: _t->handle_profiler_status_update((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
+        case 98: _t->profiler_show(); break;
+        case 99: _t->handle_octave_ready(); break;
+        case 100: _t->handle_set_path_dialog_request(); break;
+        case 101: _t->find_files((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
+        case 102: _t->find_files(); break;
+        case 103: _t->find_files_finished((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
+        case 104: _t->set_screen_size((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
+        case 105: _t->clipboard_has_changed(); break;
+        case 106: _t->clear_clipboard(); break;
+        case 107: { QList<octave_dock_widget*> _r = _t->get_dock_widget_list();
             if (_a[0]) *reinterpret_cast<QList<octave_dock_widget*>*>(_a[0]) = std::move(_r); }  break;
-        case 109: _t->disable_menu_shortcuts((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
-        case 110: _t->restore_create_file_setting(); break;
-        case 111: _t->set_file_encoding((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
-        case 112: _t->warning_function_not_found((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
+        case 108: _t->disable_menu_shortcuts((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
+        case 109: _t->restore_create_file_setting(); break;
+        case 110: _t->set_file_encoding((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
+        case 111: _t->warning_function_not_found((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
         default: ;
         }
     }
@@ -747,14 +741,14 @@ int octave::main_window::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
     if (_id < 0)
         return _id;
     if (_c == QMetaObject::InvokeMetaMethod) {
-        if (_id < 113)
+        if (_id < 112)
             qt_static_metacall(this, _c, _id, _a);
-        _id -= 113;
+        _id -= 112;
     }
     if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
-        if (_id < 113)
+        if (_id < 112)
             qt_static_metacall(this, _c, _id, _a);
-        _id -= 113;
+        _id -= 112;
     }
     return _id;
 }
